summaryrefslogtreecommitdiffstats
path: root/Modules
diff options
context:
space:
mode:
Diffstat (limited to 'Modules')
-rw-r--r--Modules/CMakeDetermineCompilerId.cmake2
-rw-r--r--Modules/CMakeFortranCompilerId.F.in2
-rw-r--r--Modules/CMakePackageConfigHelpers.cmake4
-rw-r--r--Modules/Compiler/IntelLLVM-DetermineCompiler.cmake2
-rw-r--r--Modules/FetchContent.cmake4
-rw-r--r--Modules/FindFLTK.cmake2
-rw-r--r--Modules/FindGettext.cmake4
-rw-r--r--Modules/FindJNI.cmake2
-rw-r--r--Modules/FindMatlab.cmake18
-rw-r--r--Modules/GNUInstallDirs.cmake2
-rw-r--r--Modules/GetPrerequisites.cmake2
-rw-r--r--Modules/Platform/ARTOS-GNU-C.cmake2
12 files changed, 23 insertions, 23 deletions
diff --git a/Modules/CMakeDetermineCompilerId.cmake b/Modules/CMakeDetermineCompilerId.cmake
index 519fe6b..448f071 100644
--- a/Modules/CMakeDetermineCompilerId.cmake
+++ b/Modules/CMakeDetermineCompilerId.cmake
@@ -320,7 +320,7 @@ Id flags: ${testflags} ${CMAKE_${lang}_COMPILER_ID_FLAGS_ALWAYS}
set(id_cl "$(CLToolExe)")
elseif(CMAKE_VS_PLATFORM_TOOLSET MATCHES "v[0-9]+_clang_.*")
set(id_cl clang.exe)
- # Executable names have choosen according documentation
+ # Executable names have been chosen according documentation
# URL: (https://software.intel.com/content/www/us/en/develop/documentation/get-started-with-dpcpp-compiler/top.html#top_GUID-A9B4C91D-97AC-450D-9742-9D895BC8AEE1)
elseif(CMAKE_VS_PLATFORM_TOOLSET MATCHES "Intel")
if(CMAKE_VS_PLATFORM_TOOLSET MATCHES "DPC\\+\\+ Compiler")
diff --git a/Modules/CMakeFortranCompilerId.F.in b/Modules/CMakeFortranCompilerId.F.in
index 7b1d68b..d0e0e46 100644
--- a/Modules/CMakeFortranCompilerId.F.in
+++ b/Modules/CMakeFortranCompilerId.F.in
@@ -26,7 +26,7 @@
PRINT *, 'INFO:compiler[IntelLLVM]'
! __INTEL_LLVM_COMPILER = VVVVRP prior to 2021.2.0, VVVVRRPP for 2021.2.0 and
! later. Look for 6 digit vs. 8 digit version number to decide encoding.
-! VVVV is no smaller than the current year when a versio is released.
+! VVVV is no smaller than the current year when a version is released.
# if __INTEL_LLVM_COMPILER < 1000000
# define COMPILER_VERSION_MAJOR DEC(__INTEL_LLVM_COMPILER/100)
# define COMPILER_VERSION_MINOR DEC(__INTEL_LLVM_COMPILER/10 % 10)
diff --git a/Modules/CMakePackageConfigHelpers.cmake b/Modules/CMakePackageConfigHelpers.cmake
index ad719ef..5813956 100644
--- a/Modules/CMakePackageConfigHelpers.cmake
+++ b/Modules/CMakePackageConfigHelpers.cmake
@@ -143,12 +143,12 @@ The ``COMPATIBILITY`` mode ``AnyNewerVersion`` means that the installed
package version will be considered compatible if it is newer or exactly the
same as the requested version. This mode should be used for packages which
are fully backward compatible, also across major versions.
-If ``SameMajorVersion`` is used instead, then the behaviour differs from
+If ``SameMajorVersion`` is used instead, then the behavior differs from
``AnyNewerVersion`` in that the major version number must be the same as
requested, e.g. version 2.0 will not be considered compatible if 1.0 is
requested. This mode should be used for packages which guarantee backward
compatibility within the same major version.
-If ``SameMinorVersion`` is used, the behaviour is the same as
+If ``SameMinorVersion`` is used, the behavior is the same as
``SameMajorVersion``, but both major and minor version must be the same as
requested, e.g version 0.2 will not be compatible if 0.1 is requested.
If ``ExactVersion`` is used, then the package is only considered compatible if
diff --git a/Modules/Compiler/IntelLLVM-DetermineCompiler.cmake b/Modules/Compiler/IntelLLVM-DetermineCompiler.cmake
index 124dafe..917a364 100644
--- a/Modules/Compiler/IntelLLVM-DetermineCompiler.cmake
+++ b/Modules/Compiler/IntelLLVM-DetermineCompiler.cmake
@@ -4,7 +4,7 @@ set(_compiler_id_pp_test "(defined(__clang__) && defined(__INTEL_CLANG_COMPILER)
set(_compiler_id_version_compute "
/* __INTEL_LLVM_COMPILER = VVVVRP prior to 2021.2.0, VVVVRRPP for 2021.2.0 and
* later. Look for 6 digit vs. 8 digit version number to decide encoding.
- * VVVV is no smaller than the current year when a versio is released.
+ * VVVV is no smaller than the current year when a version is released.
*/
#if __INTEL_LLVM_COMPILER < 1000000L
# define @PREFIX@COMPILER_VERSION_MAJOR @MACRO_DEC@(__INTEL_LLVM_COMPILER/100)
diff --git a/Modules/FetchContent.cmake b/Modules/FetchContent.cmake
index 88f7ed6..f5de930 100644
--- a/Modules/FetchContent.cmake
+++ b/Modules/FetchContent.cmake
@@ -296,7 +296,7 @@ is simpler and provides additional features over the pattern above.
The ``FetchContent_Populate()`` command also supports a syntax allowing the
content details to be specified directly rather than using any saved
details. This is more low-level and use of this form is generally to be
- avoided in favour of using saved content details as outlined above.
+ avoided in favor of using saved content details as outlined above.
Nevertheless, in certain situations it can be useful to invoke the content
population as an isolated operation (typically as part of implementing some
other higher level feature or when using CMake in script mode):
@@ -1053,7 +1053,7 @@ function(FetchContent_Populate contentName)
# Don't set global properties, or record that we did this population, since
# this was a direct call outside of the normal declared details form.
# We only want to save values in the global properties for content that
- # honours the hierarchical details mechanism so that projects are not
+ # honors the hierarchical details mechanism so that projects are not
# robbed of the ability to override details set in nested projects.
return()
endif()
diff --git a/Modules/FindFLTK.cmake b/Modules/FindFLTK.cmake
index e1e239a..bab7256 100644
--- a/Modules/FindFLTK.cmake
+++ b/Modules/FindFLTK.cmake
@@ -108,7 +108,7 @@ if(APPLE)
set( FLTK_PLATFORM_DEPENDENT_LIBS "-framework Carbon -framework Cocoa -framework ApplicationServices -lz")
endif()
-# If FLTK_INCLUDE_DIR is already defined we assigne its value to FLTK_DIR
+# If FLTK_INCLUDE_DIR is already defined we assign its value to FLTK_DIR.
if(FLTK_INCLUDE_DIR)
set(FLTK_DIR ${FLTK_INCLUDE_DIR})
endif()
diff --git a/Modules/FindGettext.cmake b/Modules/FindGettext.cmake
index 252f2ae..99e2887 100644
--- a/Modules/FindGettext.cmake
+++ b/Modules/FindGettext.cmake
@@ -39,7 +39,7 @@ LANGUAGES <lang1> <lang2> ... )
If INSTALL_DESTINATION is given then automatically install rules will
be created, the language subdirectory will be taken into account
(by default use share/locale/).
- If ALL is specified, the pot file is processed when building the all traget.
+ If ALL is specified, the pot file is processed when building the all target.
It creates a custom target "potfile".
GETTEXT_PROCESS_PO_FILES( <lang> [ALL] [INSTALL_DESTINATION <dir>]
@@ -51,7 +51,7 @@ PO_FILES <po1> <po2> ... )
If INSTALL_DESTINATION is given then automatically install rules will
be created, the language subdirectory will be taken into account
(by default use share/locale/).
- If ALL is specified, the po files are processed when building the all traget.
+ If ALL is specified, the po files are processed when building the all target.
It creates a custom target "pofiles".
.. versionadded:: 3.2
diff --git a/Modules/FindJNI.cmake b/Modules/FindJNI.cmake
index 5aa2d60..e4f60b3 100644
--- a/Modules/FindJNI.cmake
+++ b/Modules/FindJNI.cmake
@@ -80,7 +80,7 @@ macro(java_append_library_directories _var)
elseif(CMAKE_SYSTEM_PROCESSOR MATCHES "^(powerpc|ppc)")
set(_java_libarch "ppc" "ppc64")
elseif(CMAKE_SYSTEM_PROCESSOR MATCHES "^sparc")
- # Both flavours can run on the same processor
+ # Both flavors can run on the same processor
set(_java_libarch "${CMAKE_SYSTEM_PROCESSOR}" "sparc" "sparcv9")
elseif(CMAKE_SYSTEM_PROCESSOR MATCHES "^(parisc|hppa)")
set(_java_libarch "parisc" "parisc64")
diff --git a/Modules/GNUInstallDirs.cmake b/Modules/GNUInstallDirs.cmake
index e149f4c..f7d8c36 100644
--- a/Modules/GNUInstallDirs.cmake
+++ b/Modules/GNUInstallDirs.cmake
@@ -352,7 +352,7 @@ macro(GNUInstallDirs_get_absolute_install_dir absvar var)
if(GGAID_extra_arg_count GREATER 0)
list(GET GGAID_extra_args 0 GGAID_dir)
else()
- # Historical behaviour: use ${dir} from caller's scope
+ # Historical behavior: use ${dir} from caller's scope
set(GGAID_dir "${dir}")
message(AUTHOR_WARNING
"GNUInstallDirs_get_absolute_install_dir called without third argument. "
diff --git a/Modules/GetPrerequisites.cmake b/Modules/GetPrerequisites.cmake
index ed5c38b..e90a9b5 100644
--- a/Modules/GetPrerequisites.cmake
+++ b/Modules/GetPrerequisites.cmake
@@ -83,7 +83,7 @@ to 1 all prerequisites will be found recursively, if set to 0 only
direct prerequisites are listed. <exclude_system> must be 0 or 1
indicating whether to include or exclude "system" prerequisites. With
<verbose> set to 0 only the full path names of the prerequisites are
-printed, set to 1 extra informatin will be displayed.
+printed, set to 1 extra information will be displayed.
::
diff --git a/Modules/Platform/ARTOS-GNU-C.cmake b/Modules/Platform/ARTOS-GNU-C.cmake
index fe8d782..bce4613 100644
--- a/Modules/Platform/ARTOS-GNU-C.cmake
+++ b/Modules/Platform/ARTOS-GNU-C.cmake
@@ -1,4 +1,4 @@
-# Define ARTOS to select proper behaviour and tell preprocessor to accept C++ style comments.
+# Define ARTOS to select proper behavior and tell preprocessor to accept C++ style comments.
string(APPEND CMAKE_C_FLAGS_INIT " -DARTOS -Xp -+")
# ac doesn't support -g properly and doesn't support the normal gcc optimization options. Just use the defaults set by ac.
string(APPEND CMAKE_C_FLAGS_DEBUG_INIT " ")
diff --git a/Modules/FindMatlab.cmake b/Modules/FindMatlab.cmake
index 2f56d15..c8df670 100644
--- a/Modules/FindMatlab.cmake
+++ b/Modules/FindMatlab.cmake
@@ -52,7 +52,7 @@ The module supports the following components:
between the release name and the version.
The variable :variable:`Matlab_ROOT_DIR` may be specified in order to give
-the path of the desired Matlab version. Otherwise, the behaviour is platform
+the path of the desired Matlab version. Otherwise, the behavior is platform
specific:
* Windows: The installed versions of Matlab/MCR are retrieved from the
@@ -83,7 +83,7 @@ Module Input Variables
^^^^^^^^^^^^^^^^^^^^^^
Users or projects may set the following variables to configure the module
-behaviour:
+behavior:
:variable:`Matlab_ROOT_DIR`
the root of the Matlab installation.
@@ -184,7 +184,7 @@ Known issues
**Symbol clash in a MEX target**
By default, every symbols inside a MEX
file defined with the command :command:`matlab_add_mex` have hidden
- visibility, except for the entry point. This is the default behaviour of
+ visibility, except for the entry point. This is the default behavior of
the MEX compiler, which lowers the risk of symbol collision between the
libraries shipped with Matlab, and the libraries to which the MEX file is
linking to. This is also the default on Windows platforms.
@@ -223,7 +223,7 @@ Reference
.. variable:: MATLAB_ADDITIONAL_VERSIONS
If set, specifies additional versions of Matlab that may be looked for.
- The variable should be a list of strings, organised by pairs of release
+ The variable should be a list of strings, organized by pairs of release
name and versions, such as follows::
set(MATLAB_ADDITIONAL_VERSIONS
@@ -856,7 +856,7 @@ endfunction()
where ``matlab_file_name`` is the ``UNITTEST_FILE`` without the extension.
``UNITTEST_PRECOMMAND``
Matlab script command to be ran before the file
- containing the test (eg. GPU device initialisation based on CMake
+ containing the test (eg. GPU device initialization based on CMake
variables).
``TIMEOUT``
the test timeout in seconds. Defaults to 180 seconds as the
@@ -1240,7 +1240,7 @@ function(_Matlab_get_version_from_root matlab_root matlab_or_mcr matlab_known_ve
endif()
endif()
# UNKNOWN is the default behaviour in case we
# - have an erroneous matlab_root
# - have an initial 'UNKNOWN'
if(matlab_or_mcr STREQUAL "MATLAB" OR matlab_or_mcr STREQUAL "UNKNOWN")
@@ -1375,7 +1375,7 @@ function(_Matlab_find_instances_osx matlab_roots)
set(_matlab_possible_roots)
# on mac, we look for the /Application paths
# this corresponds to the behaviour on Windows. On Linux, we do not have
# any other guess.
matlab_get_supported_releases(_matlab_releases)
if(MATLAB_FIND_DEBUG)
@@ -1416,7 +1416,7 @@ function(_Matlab_find_instances_from_path matlab_roots)
set(_matlab_possible_roots)
# At this point, we have no other choice than trying to find it from PATH.
- # If set by the user, this wont change
+ # If set by the user, this won't change.
find_program(
_matlab_main_tmp
NAMES matlab)
@@ -1552,7 +1552,7 @@ if(_numbers_of_matlab_roots GREATER 0)
# adding a warning in case of ambiguity
if(_numbers_of_matlab_roots GREATER 3 AND MATLAB_FIND_DEBUG)
message(WARNING "[MATLAB] Found several distributions of Matlab. Setting the current version to ${Matlab_VERSION_STRING} (located ${Matlab_ROOT_DIR})."
- " If this is not the desired behaviour, use the EXACT keyword or provide the -DMatlab_ROOT_DIR=... on the command line")
+ " If this is not the desired behavior, use the EXACT keyword or provide the -DMatlab_ROOT_DIR=... on the command line")
endif()
endif()
endif()
@@ -1240,7 +1240,7 @@ function(_Matlab_get_version_from_root matlab_root matlab_or_mcr matlab_known_ve
endif()
endif()
- # UNKNOWN is the default behaviour in case we
+ # UNKNOWN is the default behavior in case we
# - have an erroneous matlab_root
# - have an initial 'UNKNOWN'
@@ -1375,7 +1375,7 @@ function(_Matlab_find_instances_osx matlab_roots)
set(_matlab_possible_roots)
# on mac, we look for the /Application paths
- # this corresponds to the behaviour on Windows. On Linux, we do not have
+ # this corresponds to the behavior on Windows. On Linux, we do not have
# any other guess.
matlab_get_supported_releases(_matlab_releases)